@@ -7,6 +7,12 @@ val pretty_format : ?std:bool -> json -> Easy_format.t
       @see <http://martin.jambon.free.fr/easy-format.html> Easy-format
   *)
 
+val pretty_print : ?std:bool -> Format.formatter -> json -> unit
+  (** Pretty-print into a {!Format.formatter}.
+      See [to_string] for the role of the optional [std] argument.
+
+      @since 1.3.1 *)
+
 val pretty_to_string : ?std:bool -> json -> string
   (** Pretty-print into a string.
       See [to_string] for the role of the optional [std] argument.
